@@ -98,25 +98,27 @@ define_columns (GdaOracleRecordsetPrivate *priv)
 		}
 
 		switch (ora_value->sql_type) {
-		case SQLT_NUM: // Numerics are coerced to string
+		case SQLT_NUM: /* Numerics are coerced to string */
 			ora_value->sql_type = SQLT_CHR;
 			break;
-		case SQLT_DAT: // Convert SQLT_DAT to OCIDate
+		case SQLT_DAT: /* Convert SQLT_DAT to OCIDate */
 			ora_value->sql_type = SQLT_ODT;
 			break;
 		}
 
-		ora_value->value = g_malloc0 (ora_value->defined_size);
+		if (ora_value->defined_size == 0)
+		    ora_value->value = NULL;
+		else
+		    ora_value->value = g_malloc0 (ora_value->defined_size+1);
 		ora_value->hdef = (OCIDefine *) 0;
 		ora_value->indicator = 0;
 		ora_value->gda_type = oracle_sqltype_to_gda_type (ora_value->sql_type);
-
 		result = OCIDefineByPos ((OCIStmt *) priv->hstmt,
 					(OCIDefine **) &(ora_value->hdef),
 					(OCIError *) priv->cdata->herr,
 					(ub4) i + 1,
 					ora_value->value,
-					ora_value->defined_size,
+					ora_value->defined_size+1,
 					(ub2) ora_value->sql_type,
 					(dvoid *) &(ora_value->indicator),
 					(ub2 *) 0,
@@ -294,7 +296,7 @@ gda_oracle_recordset_get_n_rows (GdaDataModel *model)
 					(ub4) OCI_DEFAULT);
 	}
 
-	// reset the result set to the beginning
+	/* reset the result set to the beginning */
 	result = OCIStmtExecute (priv_data->cdata->hservice,
 				priv_data->hstmt,
 				priv_data->cdata->herr,
@@ -303,6 +305,7 @@ gda_oracle_recordset_get_n_rows (GdaDataModel *model)
 				(CONST OCISnapshot *) NULL,
 				(OCISnapshot *) NULL,
 				OCI_DEFAULT);
+	
 	if (!gda_oracle_check_result (result, priv_data->cnc, priv_data->cdata, 
 		OCI_HTYPE_ERROR, "Could not execute Oracle statement")) {
 		return 0;
@@ -430,7 +433,7 @@ gda_oracle_recordset_get_value_at (GdaDataModel *model, gint col, gint row)
 }
 
 static gboolean
-gda_oracle_recordset_is_editable (GdaDataModel *model)
+gda_oracle_recordset_is_updatable (GdaDataModel *model)
 {
 	GdaCommandType cmd_type;
 	GdaOracleRecordset *recset = (GdaOracleRecordset *) model;
@@ -454,8 +457,8 @@ gda_oracle_recordset_append_row (GdaDataModel *model, const GList *values)
 
 	g_return_val_if_fail (GDA_IS_ORACLE_RECORDSET (recset), NULL);
 	g_return_val_if_fail (values != NULL, NULL);
-	g_return_val_if_fail (gda_data_model_is_editable (model), NULL);
-	g_return_val_if_fail (gda_data_model_is_editing (model), NULL);
+	g_return_val_if_fail (gda_data_model_is_updatable (model), NULL);
+	g_return_val_if_fail (gda_data_model_has_changed (model), NULL);
 	g_return_val_if_fail (recset->priv != NULL, 0);
 
 	priv_data = recset->priv;
@@ -559,7 +562,7 @@ gda_oracle_recordset_class_init (GdaOracleRecordsetClass *klass)
 	model_class->describe_column = gda_oracle_recordset_describe_column;
 	model_class->get_row = gda_oracle_recordset_get_row;
 	model_class->get_value_at = gda_oracle_recordset_get_value_at;
-	model_class->is_editable = gda_oracle_recordset_is_editable;
+	model_class->is_updatable = gda_oracle_recordset_is_updatable;
 	model_class->append_row = gda_oracle_recordset_append_row;
 	model_class->remove_row = gda_oracle_recordset_remove_row;
 	model_class->update_row = gda_oracle_recordset_update_row;
@@ -602,10 +605,8 @@ gda_oracle_recordset_finalize (GObject *object)
 	recset->priv->rows = NULL;
 
 	g_list_foreach (priv_data->ora_values, (GFunc) gda_oracle_free_values, NULL);
-
 	if (priv_data->hstmt)
 		OCIHandleFree ((dvoid *) priv_data->hstmt, OCI_HTYPE_STMT);
-
 	parent_class->finalize (object);
 }
 
@@ -635,8 +636,8 @@ gda_oracle_recordset_get_type (void)
 
 GdaOracleRecordset *
 gda_oracle_recordset_new (GdaConnection *cnc, 
-				GdaOracleConnectionData *cdata,
-				OCIStmt *stmthp)
+			  GdaOracleConnectionData *cdata,
+			  OCIStmt *stmthp)
 {
 	GdaOracleRecordset *recset;
 	ub4 parcount;
@@ -645,11 +646,11 @@ gda_oracle_recordset_new (GdaConnection *cnc,
 	g_return_val_if_fail (cdata != NULL, NULL);
 
 	OCIAttrGet ((dvoid *) stmthp,
-			(ub4) OCI_HTYPE_STMT,
-			(dvoid *) &parcount, 
-			0,
-			(ub4) OCI_ATTR_PARAM_COUNT,
-			cdata->herr);
+		    (ub4) OCI_HTYPE_STMT,
+		    (dvoid *) &parcount, 
+		    0,
+		    (ub4) OCI_ATTR_PARAM_COUNT,
+		    cdata->herr);
 
 	recset = g_object_new (GDA_TYPE_ORACLE_RECORDSET, NULL);
 	recset->priv->nrows = -1;
